@@ -1,4 +1,4 @@
-use crate::parser::script::{evaluate_script, Type};
+use crate::parser::script::evaluate_script;
 use bitcoin::{Address, Block, BlockHash, Transaction, TxIn, TxOut, Txid};
 use serde::{Deserialize, Serialize};
 
@@ -21,7 +21,7 @@ use serde::{Deserialize, Serialize};
 /// - `output public script key hash`
 ///
 /// `SBlock` reduces the amount of data memorized or transferred.
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Clone, PartialEq, Eq, Debug)]
 pub struct SBlock {
     pub header: SBlockHeader,
     pub txdata: Vec<STransaction>,
@@ -41,7 +41,7 @@ impl From<Block> for SBlock {
     }
 }
 
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Clone, PartialEq, Eq, Debug)]
 pub struct SBlockHeader {
     pub block_hash: BlockHash,
     pub time: u32,
@@ -67,7 +67,7 @@ impl SBlockHeader {
 /// - `output public script key hash`
 ///
 /// It reduces the amount of data memorized or transferred (to python).
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Clone, PartialEq, Eq, Debug)]
 pub struct STransaction {
     pub txid: Txid,
     /// List of inputs
@@ -86,7 +86,7 @@ impl From<Transaction> for STransaction {
     }
 }
 
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Clone, PartialEq, Eq, Debug)]
 pub struct STxIn {
     pub txid: Txid,
     pub vout: u32,
@@ -101,11 +101,10 @@ impl From<TxIn> for STxIn {
     }
 }
 
-#[derive(Serialize, Deserialize, Clone)]
+#[derive(Serialize, Deserialize, Clone, PartialEq, Eq, Debug)]
 pub struct STxOut {
     pub value: u64,
-    pub script_type: Type,
-    pub addresses: Vec<Address>,
+    pub addresses: Box<[Address]>,
 }
 
 impl From<TxOut> for STxOut {
@@ -113,8 +112,7 @@ impl From<TxOut> for STxOut {
         let eval = evaluate_script(&out.script_pubkey, bitcoin::Network::Bitcoin);
         STxOut {
             value: out.value,
-            script_type: eval.pattern,
-            addresses: eval.addresses,
+            addresses: eval.addresses.into_boxed_slice(),
         }
     }
 }
